[devel] Imported from libpng-1.5.4beta01.tar
diff --git a/ANNOUNCE b/ANNOUNCE
index f1b0d2e..fc933e8 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
 
-Libpng 1.5.3beta12 - June 13, 2011
+Libpng 1.5.4beta01 - June 14, 2011
 
 This is not intended to be a public release.  It will be replaced
 within a few weeks by a public version or by another test version.
@@ -9,20 +9,20 @@
 Source files with LF line endings (for Unix/Linux) and with a
 "configure" script
 
-   1.5.3beta12.tar.xz (LZMA-compressed, recommended)
-   1.5.3beta12.tar.gz
-   1.5.3beta12.tar.bz2
+   1.5.4beta01.tar.xz (LZMA-compressed, recommended)
+   1.5.4beta01.tar.gz
+   1.5.4beta01.tar.bz2
 
 Source files with CRLF line endings (for Windows), without the
 "configure" script
 
-   lp153b12.7z  (LZMA-compressed, recommended)
-   lp153b12.zip
+   lp154b01.7z  (LZMA-compressed, recommended)
+   lp154b01.zip
 
 Other information:
 
-   1.5.3beta12-README.txt
-   1.5.3beta12-LICENSE.txt
+   1.5.4beta01-README.txt
+   1.5.4beta01-LICENSE.txt
 
 Changes since the last public release (1.5.2):
 
@@ -181,7 +181,12 @@
     necessarily fully supportable, particularly png_strncpy and png_snprintf.
   Added log option to pngvalid.c and attempted to improve gamma messages.
 
-Version 1.5.3beta12 [June 13, 2011]
+Version 1.5.3 [omitted]
+  People found the presence of a beta release following an rc release
+    to be confusing; therefore we bump the version to libpng-1.5.4beta01
+    and there will be no libpng-1.5.3 release.
+
+Version 1.5.4beta01 [June 14, 2011]
   Made it possible to undefine PNG_READ_16_TO_8_ACCURATE_SCALE_SUPPORTED
     to get the same (inaccurate) output as libpng-1.5.2 and earlier.
   Moved definitions of PNG_HAVE_IHDR, PNG_AFTER_IDAT, and PNG_HAVE_PLTE
diff --git a/CHANGES b/CHANGES
index a8c4fa0..9e802c4 100644
--- a/CHANGES
+++ b/CHANGES
@@ -3444,7 +3444,12 @@
     necessarily fully supportable, particularly png_strncpy and png_snprintf.
   Added log option to pngvalid.c and attempted to improve gamma messages.
   
-Version 1.5.3beta12 [June 13, 2011]
+Version 1.5.3 [omitted]
+  People found the presence of a beta release following an rc release
+    to be confusing; therefore we bump the version to libpng-1.5.4beta01
+    and there will be no libpng-1.5.3 release.
+
+Version 1.5.4beta01 [June 14, 2011]
   Made it possible to undefine PNG_READ_16_TO_8_ACCURATE_SCALE_SUPPORTED
     to get the same (inaccurate) output as libpng-1.5.2 and earlier.
   Moved definitions of PNG_HAVE_IHDR, PNG_AFTER_IDAT, and PNG_HAVE_PLTE
diff --git a/CMakeLists.txt b/CMakeLists.txt
index ad4bcef..1b38bba 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -33,7 +33,7 @@
 
 set(PNGLIB_MAJOR 1)
 set(PNGLIB_MINOR 5)
-set(PNGLIB_RELEASE 3)
+set(PNGLIB_RELEASE 4)
 set(PNGLIB_NAME libpng${PNGLIB_MAJOR}${PNGLIB_MINOR})
 set(PNGLIB_VERSION ${PNGLIB_MAJOR}.${PNGLIB_MINOR}.${PNGLIB_RELEASE})
 
@@ -260,7 +260,7 @@
 # SET UP LINKS
 if(PNG_SHARED)
   set_target_properties(${PNG_LIB_NAME} PROPERTIES
-#   VERSION 15.${PNGLIB_RELEASE}.1.5.3beta11
+#   VERSION 15.${PNGLIB_RELEASE}.1.5.4beta01
     VERSION 15.${PNGLIB_RELEASE}.0
     SOVERSION 15
     CLEAN_DIRECT_OUTPUT 1)
diff --git a/LICENSE b/LICENSE
index ab205af..97ba1f1 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.3beta11, June 11, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.4beta01, June 14, 2011, are
 Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-June 11, 2011
+June 14, 2011
diff --git a/Makefile.am b/Makefile.am
index f5e6403..af2f58b 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -162,7 +162,7 @@
 	test -z "$(CPPFLAGS)"
 	echo "com @PNGLIB_VERSION@ STANDARD API DEFINITION" |\
 	$(AWK) -f ${srcdir}/scripts/options.awk out=dfn1.out\
-	    logunsupported=3 - ${srcdir}/scripts/pnglibconf.dfa 1>&2
+	    logunsupported=4 - ${srcdir}/scripts/pnglibconf.dfa 1>&2
 	$(AWK) -f ${srcdir}/scripts/options.awk out=dfn2.out dfn1.out 1>&2
 	rm dfn1.out
 	mv dfn2.out $@
diff --git a/README b/README
index c35fc27..ff3d277 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.3beta11 - June 11, 2011 (shared library 15.0)
+README for libpng version 1.5.4beta01 - June 14, 2011 (shared library 15.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/configure b/configure
index 82a1769..33e841a 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.68 for libpng 1.5.3beta11.
+# Generated by GNU Autoconf 2.68 for libpng 1.5.4beta01.
 #
 # Report bugs to <png-mng-implement@lists.sourceforge.net>.
 #
@@ -570,8 +570,8 @@
 # Identity of this package.
 PACKAGE_NAME='libpng'
 PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.5.3beta11'
-PACKAGE_STRING='libpng 1.5.3beta11'
+PACKAGE_VERSION='1.5.4beta01'
+PACKAGE_STRING='libpng 1.5.4beta01'
 PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
 PACKAGE_URL=''
 
@@ -1307,7 +1307,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures libpng 1.5.3beta11 to adapt to many kinds of systems.
+\`configure' configures libpng 1.5.4beta01 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1377,7 +1377,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of libpng 1.5.3beta11:";;
+     short | recursive ) echo "Configuration of libpng 1.5.4beta01:";;
    esac
   cat <<\_ACEOF
 
@@ -1485,7 +1485,7 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-libpng configure 1.5.3beta11
+libpng configure 1.5.4beta01
 generated by GNU Autoconf 2.68
 
 Copyright (C) 2010 Free Software Foundation, Inc.
@@ -1908,7 +1908,7 @@
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by libpng $as_me 1.5.3beta11, which was
+It was created by libpng $as_me 1.5.4beta01, which was
 generated by GNU Autoconf 2.68.  Invocation command line was
 
   $ $0 $@
@@ -2723,7 +2723,7 @@
 
 # Define the identity of the package.
  PACKAGE='libpng'
- VERSION='1.5.3beta11'
+ VERSION='1.5.4beta01'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -2787,10 +2787,10 @@
 
 
 
-PNGLIB_VERSION=1.5.3beta11
+PNGLIB_VERSION=1.5.4beta01
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=5
-PNGLIB_RELEASE=3
+PNGLIB_RELEASE=4
 
 
 
@@ -13040,7 +13040,7 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by libpng $as_me 1.5.3beta11, which was
+This file was extended by libpng $as_me 1.5.4beta01, which was
 generated by GNU Autoconf 2.68.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -13106,7 +13106,7 @@
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-libpng config.status 1.5.3beta11
+libpng config.status 1.5.4beta01
 configured by $0, generated by GNU Autoconf 2.68,
   with options \\"\$ac_cs_config\\"
 
diff --git a/configure.ac b/configure.ac
index 6a09019..1647b66 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,15 +18,15 @@
 
 dnl Version number stuff here:
 
-AC_INIT([libpng], [1.5.3beta11], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.5.4beta01], [png-mng-implement@lists.sourceforge.net])
 AM_INIT_AUTOMAKE
 dnl stop configure from automagically running automake
 AM_MAINTAINER_MODE
 
-PNGLIB_VERSION=1.5.3beta11
+PNGLIB_VERSION=1.5.4beta01
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=5
-PNGLIB_RELEASE=3
+PNGLIB_RELEASE=4
 
 dnl End of version number stuff
 
diff --git a/libpng-manual.txt b/libpng-manual.txt
index b073c4b..0a94c4d 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.3beta11 - June 11, 2011
+ libpng version 1.5.4beta01 - June 14, 2011
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.3beta11 - June 11, 2011
+ libpng versions 0.97, January 1998, through 1.5.4beta01 - June 14, 2011
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
 
@@ -4417,13 +4417,13 @@
 
 XIV. Y2K Compliance in libpng
 
-June 11, 2011
+June 14, 2011
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.3beta11 are Y2K compliant.  It is my belief that earlier
+upward through 1.5.4beta01 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index 57e4bb5..a78c803 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "June 11, 2011"
+.TH LIBPNG 3 "June 14, 2011"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.3beta11
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.4beta01
 .SH SYNOPSIS
 \fI\fB
 
@@ -951,7 +951,7 @@
 .SH LIBPNG.TXT
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.3beta11 - June 11, 2011
+ libpng version 1.5.4beta01 - June 14, 2011
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -962,7 +962,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.3beta11 - June 11, 2011
+ libpng versions 0.97, January 1998, through 1.5.4beta01 - June 14, 2011
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
 
@@ -5368,13 +5368,13 @@
 
 .SH XIV. Y2K Compliance in libpng
 
-June 11, 2011
+June 14, 2011
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.3beta11 are Y2K compliant.  It is my belief that earlier
+upward through 1.5.4beta01 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
@@ -5565,7 +5565,8 @@
  1.5.2               15    10502  15.so.15.2[.0]
  1.5.3beta01-10      15    10503  15.so.15.3[.0]
  1.5.3rc01-02        15    10503  15.so.15.3[.0]
- 1.5.3beta11         15    10503  15.so.15.3[.0]
+ 1.5.3beta11 [no 1.5.3] 15 10503  15.so.15.3[.0]
+ 1.5.4beta01         15    10504  15.so.15.4[.0]
 
 Henceforth the source version will match the shared-library minor
 and patch numbers; the shared-library major version number will be
@@ -5622,7 +5623,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.5.3beta11 - June 11, 2011:
+Libpng version 1.5.4beta01 - June 14, 2011:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -5645,7 +5646,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.3beta11, June 11, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.4beta01, June 14, 2011, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -5744,7 +5745,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-June 11, 2011
+June 14, 2011
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index dffcf39..893b5d4 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "June 11, 2011"
+.TH LIBPNGPF 3 "June 14, 2011"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.3beta11
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.4beta01
 (private functions)
 .SH SYNOPSIS
 \fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index d52cd9e..a1586ab 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "June 11, 2011"
+.TH PNG 5 "June 14, 2011"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/png.c b/png.c
index 565c0db..5fece6e 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
 #include "pngpriv.h"
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_3beta12 Your_png_h_is_not_version_1_5_3beta12;
+typedef png_libpng_version_1_5_4beta01 Your_png_h_is_not_version_1_5_4beta01;
 
 /* Tells libpng that we have already handled the first "num_bytes" bytes
  * of the PNG file signature.  If the PNG data is embedded into another
@@ -617,13 +617,13 @@
 #else
 #  ifdef __STDC__
    return PNG_STRING_NEWLINE \
-     "libpng version 1.5.3beta12 - June 13, 2011" PNG_STRING_NEWLINE \
+     "libpng version 1.5.4beta01 - June 14, 2011" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2011 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE;
 #  else
-      return "libpng version 1.5.3beta12 - June 13, 2011\
+      return "libpng version 1.5.4beta01 - June 14, 2011\
       Copyright (c) 1998-2011 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 92347ca..adaf7db 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.5.3beta11 - June 11, 2011
+ * libpng version 1.5.4beta01 - June 14, 2011
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index 478d04f..2e74fc7 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1794,4 +1794,4 @@
 }
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_3beta11 Your_png_h_is_not_version_1_5_3beta11;
+typedef png_libpng_version_1_5_4beta01 Your_png_h_is_not_version_1_5_4beta01;
diff --git a/pngvalid.c b/pngvalid.c
index 46607c9..d55a5d8 100644
--- a/pngvalid.c
+++ b/pngvalid.c
@@ -5263,7 +5263,7 @@
       if (that->alpha_sBIT > 8) that->alpha_sBIT = 8;
 
 #     ifndef PNG_READ_16_TO_8_ACCURATE_SCALE_SUPPORTED
-         /* The strip 16 algoirithm drops the low 8 bits rather than calculating
+         /* The strip 16 algorithm drops the low 8 bits rather than calculating
           * 1/257, so we need to adjust the permitted errors appropriately:
           */
          {
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index cc0af49..3d3e684 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.5.3beta11 - June 11, 2011
+libpng version 1.5.4beta01 - June 14, 2011
 
 Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index e65c6a9..a36e9d5 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source
  *
- * libpng version 1.5.3beta11 - June 11, 2011
+ * libpng version 1.5.4beta01 - June 14, 2011
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index 5dc33d5..cb65583 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
 
-Makefiles for  libpng version 1.5.3beta11 - June 11, 2011
+Makefiles for  libpng version 1.5.4beta01 - June 14, 2011
 
 pnglibconf.h.prebuilt       =>  Stores configuration settings
  makefile.linux    =>  Linux/ELF makefile
-                       (gcc, creates libpng15.so.15.1.5.3beta11)
+                       (gcc, creates libpng15.so.15.1.5.4beta01)
  makefile.gcc      =>  Generic makefile (gcc, creates static libpng.a)
  makefile.knr      =>  Archaic UNIX Makefile that converts files with
                        ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@
  makefile.dec      =>  DEC Alpha UNIX makefile
  makefile.dj2      =>  DJGPP 2 makefile
  makefile.elf      =>  Linux/ELF makefile symbol versioning,
-                       (gcc, creates libpng15.so.15.1.5.3beta11)
+                       (gcc, creates libpng15.so.15.1.5.4beta01)
  makefile.freebsd  =>  FreeBSD makefile
  makefile.gcc      =>  Generic gcc makefile
  makefile.hpgcc    =>  HPUX makefile using gcc
@@ -35,12 +35,12 @@
  makefile.os2      =>  OS/2 Makefile (gcc and emx, requires libpng.def)
  makefile.sco      =>  For SCO OSr5  ELF and Unixware 7 with Native cc
  makefile.sggcc    =>  Silicon Graphics (gcc,
-                       creates libpng15.so.15.1.5.3beta11)
+                       creates libpng15.so.15.1.5.4beta01)
  makefile.sgi      =>  Silicon Graphics IRIX makefile (cc, creates static lib)
  makefile.solaris  =>  Solaris 2.X makefile (gcc,
-                       creates libpng15.so.15.1.5.3beta11)
+                       creates libpng15.so.15.1.5.4beta01)
  makefile.so9      =>  Solaris 9 makefile (gcc,
-                       creates libpng15.so.15.1.5.3beta11)
+                       creates libpng15.so.15.1.5.4beta01)
  makefile.std      =>  Generic UNIX makefile (cc, creates static libpng.a)
  makefile.sunos    =>  Sun makefile
  makefile.32sunu   =>  Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index a62e061..ed1df5d 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
 
 # Modeled after libxml-config.
 
-version=1.5.3beta11
+version=1.5.4beta01
 prefix=""
 libdir=""
 libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index c2b76e5..25bd173 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@
 
 Name: libpng
 Description: Loads and saves PNG files
-Version: 1.5.3beta11
+Version: 1.5.4beta01
 Libs: -L${libdir} -lpng15
 Cflags: -I${includedir}
diff --git a/scripts/makefile.cegcc b/scripts/makefile.cegcc
index 618da20..57414dd 100644
--- a/scripts/makefile.cegcc
+++ b/scripts/makefile.cegcc
@@ -23,7 +23,7 @@
 
 VERMAJ = 1
 VERMIN = 5
-VERMIC = 3
+VERMIC = 4
 VER = $(VERMAJ).$(VERMIN).$(VERMIC)
 NAME = libpng
 PACKAGE = $(NAME)-$(VER)
diff --git a/scripts/makefile.linux b/scripts/makefile.linux
index 957ff8c..f91d464 100644
--- a/scripts/makefile.linux
+++ b/scripts/makefile.linux
@@ -10,7 +10,7 @@
 # Library name:
 LIBNAME = libpng15
 PNGMAJ = 15
-RELEASE = 3
+RELEASE = 4
 
 # Shared library names:
 LIBSO=$(LIBNAME).so
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 6ed2a72..003d965 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@
 
 LIB=	png15
 SHLIB_MAJOR=	0
-SHLIB_MINOR=	1.5.3beta11
+SHLIB_MINOR=	1.5.4beta01
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index 08d2a90..1eb3bf4 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@
 
 LIB=	png
 SHLIB_MAJOR=	15
-SHLIB_MINOR=	1.5.3beta11
+SHLIB_MINOR=	1.5.4beta01
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 0d976bf..12b7a85 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@
 MANDIR= ${PREFIX}/man/cat
 
 SHLIB_MAJOR=	15
-SHLIB_MINOR=	1.5.3beta11
+SHLIB_MINOR=	1.5.4beta01
 
 LIB=	png
 SRCS=	png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/pnglibconf.dfa b/scripts/pnglibconf.dfa
index 0e95ec7..429c632 100644
--- a/scripts/pnglibconf.dfa
+++ b/scripts/pnglibconf.dfa
@@ -346,10 +346,8 @@
 
 option BUILD_GRAYSCALE_PALETTE
 
-# This is no longer used - the scaling is always accurate - but the definition
-# is left in for older applications (including pngvalid) that check it.  Do not
-# turn it off!
 option READ_16_TO_8_ACCURATE_SCALE requires READ
+option LEGACY_READ_16_TO_8_ACCURATE_SCALE disabled
 
 # IN DEVELOPMENT
 # These are currently experimental features; define them if you want
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index dd470dd..54331ec 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -61,6 +61,7 @@
 #define PNG_INFO_IMAGE_SUPPORTED
 #define PNG_IO_STATE_SUPPORTED
 #define PNG_iTXt_SUPPORTED
+/*#undef PNG_LEGACY_READ_16_TO_8_ACCURATE_SCALE_SUPPORTED*/
 #define PNG_MNG_FEATURES_SUPPORTED
 #define PNG_oFFs_SUPPORTED
 #define PNG_pCAL_SUPPORTED
diff --git a/scripts/symbols.def b/scripts/symbols.def
index 671a5a3..457673c 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -5,7 +5,7 @@
 LIBRARY
 
 EXPORTS
-;Version 1.5.3beta11
+;Version 1.5.4beta01
  png_access_version_number @1
  png_set_sig_bytes @2
  png_sig_cmp @3
diff --git a/png.h b/png.h
index fd18169..f5d8681 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.5.3beta12 - June 13, 2011
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.5.3beta12 - June 13, 2011: Glenn
  *   See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -152,7 +152,8 @@
  *    1.5.2                   15    10502  15.so.15.2[.0]
  *    1.5.3beta01-10          15    10503  15.so.15.3[.0]
  *    1.5.3rc01-02            15    10503  15.so.15.3[.0]
- *    1.5.3beta11-12          15    10503  15.so.15.3[.0]
+ *    1.5.3beta11 [no 1.5.3]  15    10503  15.so.15.3[.0]
+ *    1.5.4beta01             15    10504  15.so.15.4[.0]
  *
  *   Henceforth the source version will match the shared-library major
  *   and minor numbers; the shared-library major version number will be
@@ -184,7 +185,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.5.3beta12, June 13, 2011, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -296,13 +297,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    June 13, 2011
+ *    June 14, 2011
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.5.3beta12 are Y2K compliant.  It is my belief that
  *    earlier versions were also Y2K compliant.
  *
  *    Libpng only has two year fields.  One is a 2-byte unsigned integer
@@ -357,9 +358,9 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.3beta12"
+#define PNG_LIBPNG_VER_STRING "1.5.4beta01"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.5.3beta12 - June 13, 2011\n"
+     " libpng version 1.5.4beta01 - June 14, 2011\n"
 
 #define PNG_LIBPNG_VER_SONUM   15
 #define PNG_LIBPNG_VER_DLLNUM  15
@@ -367,12 +368,12 @@
 /* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
 #define PNG_LIBPNG_VER_MAJOR   1
 #define PNG_LIBPNG_VER_MINOR   5
-#define PNG_LIBPNG_VER_RELEASE 3
+#define PNG_LIBPNG_VER_RELEASE 4
 /* This should match the numeric part of the final component of
  * PNG_LIBPNG_VER_STRING, omitting any leading zero:
  */
 
-#define PNG_LIBPNG_VER_BUILD  12
+#define PNG_LIBPNG_VER_BUILD  01
 
 /* Release Status */
 #define PNG_LIBPNG_BUILD_ALPHA    1
@@ -397,7 +398,7 @@
  * version 1.0.0 was mis-numbered 100 instead of 10000).  From
  * version 1.0.1 it's    xxyyzz, where x=major, y=minor, z=release
  */
-#define PNG_LIBPNG_VER 10503 /* 1.5.3 */
+#define PNG_LIBPNG_VER 10504 /* 1.5.4 */
 
 /* Library configuration: these options cannot be changed after
  * the library has been built.
@@ -519,7 +520,7 @@
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef char* png_libpng_version_1_5_3beta12;
+typedef char* png_libpng_version_1_5_4beta01;
 
 /* Three color definitions.  The order of the red, green, and blue, (and the
  * exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.5.3beta12 - June 13, 2011
+ * libpng version 1.5.4beta01 - June 14, 2011
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.5.3beta12 - June 13, 2011: Glenn
+ *   libpng versions 0.97, January 1998, through 1.5.4beta01 - June 14, 2011: Glenn
  *   See also "Contributing Authors", below.
  *
@@ -184,7 +185,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.5.3beta12, June 13, 2011, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.4beta01, June 14, 2011, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
@@ -296,13 +297,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.5.3beta12 are Y2K compliant.  It is my belief that
+ *    upward through 1.5.4beta01 are Y2K compliant.  It is my belief that
  *    earlier versions were also Y2K compliant.
  *